@@ -1,9 +1,9 @@
-#!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
-from pygithub3.requests.base import Request, ValidationError
+from pygithub3.requests.base import Request
 from pygithub3.resources.issues import Event
 
+
 class List_by_issue(Request):
 
     uri = 'repos/{user}/{repo}/issues/{number}/events'
